    		@ beacon
    			@ messenger

    			@ transmitter
    				@ transvoyance
    					@ televoyance

    			@ nerves

    			@ alert
    				@ alarm
    					@ siren

    			@ radio
    				@ transceiver

    			@ communication

    			@ phones
    				@ audio
    				@ phonetics
    				@ amp
    				@ ocarina

    			@ sign
    				@ signal

    			@ lighthouse

    			@ instruments

    			@ organ
    				@ keys

    		@ features
    			@ shows

    		@ conferencing
    			@ communications
    			@ talks

    		@ region
    			@ metropolis
    				@ bazaar

    			@ field
    				@ meadow

    			@ zone

    			@ wormholes

    			@ galaxies

    			@ universe

    		@ vehicles
    			@ ships

    		@ utilities
    			@ machines

    			@ rigs
    				@ calculators
    				@ trinkets

    			@ toys

    			@ circuits

    		@ devourers

    		@ simulators
    		@ webs